@@ -3,8 +3,9 @@ import json
 from typing import Union, List
 
 from django.core.exceptions import NON_FIELD_ERRORS, ValidationError
-from django.forms import ModelChoiceField, ModelMultipleChoiceField
+from django.forms import ModelChoiceField, ModelMultipleChoiceField, fields_for_model
 from django.forms.forms import DeclarativeFieldsMetaclass
+from django.forms.models import ModelFormOptions
 from django.utils.translation import gettext as _
 
 from .exceptions import RequestValidationError, UnsupportedMediaType, ApiFormException
@@ -214,5 +215,45 @@ class BaseForm(object):
         return obj
 
 
+class ModelForm(BaseForm, metaclass=DeclarativeFieldsMetaclass):
+    """
+    SUPER EXPERIMENTAL
+    """
+    def __new__(cls, *args, **kwargs):
+        new_class = super().__new__(cls, **kwargs)
+        config = getattr(cls, 'Meta', None)
+
+        model_opts = ModelFormOptions(getattr(config.model, '_meta', None))
+        model_opts.exclude = getattr(config, 'exclude', tuple())
+
+        fields = fields_for_model(
+            model=model_opts.model,
+            fields=None,
+            exclude=model_opts.exclude,
+            widgets=None,
+            formfield_callback=None,
+            localized_fields=model_opts.localized_fields,
+            labels=model_opts.labels,
+            help_texts=model_opts.help_texts,
+            error_messages=model_opts.error_messages,
+            field_classes=model_opts.field_classes,
+            apply_limit_choices_to=False,
+        )
+
+        # AutoField has to be added manually
+        # Do not add AutoFields right now
+        # if config.model._meta.auto_field and config.model._meta.auto_field.attname not in model_opts.exclude:
+        #     fields[config.model._meta.auto_field.attname] = IntegerField()
+
+        fields.update(new_class.declared_fields)
+        # Remove None value keys
+        fields = {k: v for k, v in fields.items() if v is not None}
+
+        new_class.base_fields = fields
+        new_class.declared_fields = fields
+
+        return new_class
+
+
 class Form(BaseForm, metaclass=DeclarativeFieldsMetaclass):
     """A collection of Fields, plus their associated data."""
